<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Om</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Forfattere</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Lettvekts WebKit-basert nettleser</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Opphavsrett © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translatorcomment>Update the dates in the copyright notice?</translatorcomment>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Opphavsrett © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Opphavsrett © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>WebKit versjon: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Språk: ordnet etter preferanse:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;ned</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Legg til...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation>Blokkert av AdBlockRule:%1</translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation>Legg til regel</translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation>Lær mer om å skrive regler...</translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation>Oppdater abonement</translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation>Bla igjennom abonementer...</translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation>Fjern abonement</translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation>AdBlock konfigurasjon</translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation>Skru på AdBlock</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation>Regel</translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation>Regel</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation>Abonemer?</translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation>Abonemer på dette AdBlock abonementet? %1</translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Legg til bokmerke</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Gi bokmerket et navn og velg hvor du vil lagre det.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Addresse</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Legg til mappe</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Fjern alle</translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation>&lt;b&gt;Vil du lagre dette passordet?&lt;/b&gt;&lt;br&gt;         Du kan se hvilke passord du har lagret og eventuelt slette dem under Egenskaper.</translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation>Aldri for denne siden</translation>
    </message>
    <message>
        <source>Not now</source>
        <translation>Ikke nå</translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation>Nettside</translation>
    </message>
    <message>
        <source>User Name</source>
        <translation>Brukernavn</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Ny mappe</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Legg til mappe</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Åpne i ny fane</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Endre navn</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Endre adresse</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Feil ved lasting av bokmerker på linje %1, rad %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Meny</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Åpne fil</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importerte %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Lagre fil</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Feil ved eksportering</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>feil ved lagring av bokmerker</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Fjern bokmerke</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Legg til bokmerke</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Bokmerkelinjen</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Bokmerkemeny</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml *.html)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml *.html)</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Feil ved lasting av html bokmerker: %1</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Navneendring</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Addresseendring</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>XBEL bokmerker</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>HTML Netscape bokmerker</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>trenger htmlToXBel verktøy</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>htmlToXBel verktøyet som følger med Arora og som trengs for å importere HTML bokmerker, er ikke installert eller er ikke i søkebanene.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Laster bokmerker</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Feil ved lasting av HTML bokmerker: %1</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Åpne i faner</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Bokmerker</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Åpne i ny &amp;fane</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Fjern</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Legg til bokmerke...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Legg til mappe...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Bokmerker</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Det er %1 vinduer og %2 faner åpne
Er du sikker på at du vil avslutte Arora?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Gjennopretningen misslyktes</translation>
    </message>
    <message>
        <source>The saved session will not being restored because last time it was restored Arora crashed.</source>
        <translation type="obsolete">Den lagrede økten blir ikke gjennoprettet siden forrige gang den ble gjnoprettet krasjet Arora.</translation>
    </message>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(Endring: %1 %2)</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Den lagrede økten blir ikke gjennoprettet siden det førte til at Arora krasjet.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation>Arora kræsjet forrige gang vi prøvde å gjennoprette denne siden. Skal vi prøve igjenn?</translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nytt vindu</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Åpne fil...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Åpne a&amp;dresse...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>La&amp;gre som...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importer bokmerker...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Eksporter bokmerker...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>&amp;Forhåndsvisning...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Skriv ut...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>&amp;Privat surfing...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Angre</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Gjennta</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Klipp</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>K&amp;opier</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Lim</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Finn</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;Kildekode</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Historie</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Fram</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Gjennoprett siste økt</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Bokmerker</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Håndter bokmerker...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Legg til bokmerke...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>V&amp;indu</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>V&amp;erktøy</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Nettsøk</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>&amp;Aktiver nettinspektøren</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>H&amp;jelp</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">Om &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigering</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Vis statuslinjen</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Skjul statuslinjen</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Vis verktøylinjen</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Skjul verktøylinjen</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Åpne nettresurs</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Nettresurser (*.html *.htm *.svg *.png *.gif *.svgz);;Alle filer (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Skriv ut dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Er du sikker på at du vil skru på privat surfing?</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Er du sikker på at du vil lukke vinduet? Du har %1 faner åpne</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation type="obsolete">Kildekoden til %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Nettinspektør</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Nettinspektøren virker kun som den skal for sider som blir lastet etter at den ble aktivert.
Vil du laste alle sider på nytt?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Avbryt lasting av denne siden</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Oppdater denne siden</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Slett privat informasjon</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Vis bokmerkelinjen</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Skjul bokmerkelinjen</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Noen handlinger relatert til dine personlige opplysninger vil bli deaktiverte når privat surfing er skrudd på:&lt;ul&gt;&lt;li&gt; Nettsider blir ikke lagt til i historien.&lt;/li&gt;&lt;li&gt; Elementer blir automatisk fjernet fra Nedlastninger vinduet.&lt;/li&gt;&lt;li&gt; Nye informasjonskapsler blir ikke lagret og gamle kan ikke åpnes.&lt;/li&gt;&lt;li&gt; Ikoner og økter blir ikke lagret.&lt;/li&gt;&lt;li&gt; Søk blir ikke lagt til i sprett-opp menyen i søkeboksen.&lt;/li&gt;&lt;/ul&gt;Du kan fremdeles klikke Tilbake og Fram intill du lukker vinduet.</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="obsolete">Finn &amp;Neste</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Finn &amp;forrige</translation>
    </message>
    <message>
        <source>Prefe&amp;rences</source>
        <translation type="obsolete">&amp;Instillinger</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Last siden på nytt</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">Gjør teksten &amp;større</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">Gjør teksten &amp;normal</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">Gjør teksten &amp;mindre</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Finn &amp;neste</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">&amp;Instillinger...</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Vis menylinjen</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Endre språk</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">&amp;Vis nettverksovervåkeren</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Lukk vinduet</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Skaler &amp;in</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>&amp;Normal skalering</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Skaler &amp;ut</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Skaler kun &amp;tekst</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Vis alle bokmerker...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Legg til mappe...</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Om &amp;%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Noen handlinger relatert til dine personlige opplysninger vil bli deaktiverte når privat surfing er skrudd på:&lt;ul&gt;&lt;li&gt; Nettsider blir ikke lagt til i historien.&lt;/li&gt;&lt;li&gt; Elementer blir automatisk fjernet fra Nedlastinger vinduet.&lt;/li&gt;&lt;li&gt; Nye informasjonskapsler blir ikke lagret og gamle kan ikke åpnes.&lt;/li&gt;&lt;li&gt; Ikoner og økter blir ikke lagret.&lt;/li&gt;&lt;li&gt; Søk blir ikke lagt til i sprett-opp menyen i søkeboksen.&lt;/li&gt;&lt;/ul&gt;Du kan fremdeles klikke Tilbake og Fram intill du lukker vinduet.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Forvalg</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Tekstkoding</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Velg &amp;alt</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Ctrl+B</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; No new network cache is written to disk.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Noen handlinger relatert til dine personlige opplysninger vil bli deaktiverte når privat surfing er skrudd på:&lt;ul&gt;&lt;li&gt; Nettsider blir ikke lagt til i historien.&lt;/li&gt;&lt;li&gt; Elementer blir automatisk fjernet fra Nedlastninger vinduet.&lt;/li&gt;&lt;li&gt; Nye informasjonskapsler blir ikke lagret og gamle kan ikke åpnes.&lt;/li&gt;&lt;li&gt; Ikoner og økter blir ikke lagret.&lt;/li&gt;&lt;li&gt; Søk blir ikke lagt til i sprett-opp menyen i søkeboksen.&lt;/li&gt;&lt;/ul&gt;Du kan fremdeles klikke Tilbake og Fram intill du lukker vinduet.</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Alternativer...</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation>Konfigurer søkemotorer...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation>&amp;AdBlock...</translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation>Så lenge privat surfing er skrudd på, vil noen handlinger være skrudd av:</translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation>Nettsider blir ikke lagt til i historien.</translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation>Nedlastninger blir automatisk fjernet fra Nedlastninger vinduet.</translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation>Nye informasjonskapsler blir ikke lagret og eksisterende informasjonskapsler kan ikke brukes.</translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation>Nettsideikoner blir ikke lagret.</translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation>Sessjoner blir ikke lagret.</translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation>Søk blir ikke lagt til i søkemenyen.</translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation>Nettverkshurtiglageret blir ikke skrevet til platelageret.</translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation>Så lenge du ikke lukker vinduet kan du fremdeles klikke Fram og Tilbake for å se sider du har åpnet.</translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation>Privat surfing</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Fjern</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Slett privat informasjon</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Slett følgende elementer:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Surfehistorie</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>&amp;Nedlastingshistorie</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>S&amp;økehistorie</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Informasjonskapsler</translation>
    </message>
    <message>
        <source>C&amp;ache</source>
        <translation type="obsolete">&amp;Hurtiglager</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>N&amp;ettside ikoner</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Slett &amp;privat informasjon</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>&amp;Mellomlagrede nettsider</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Last</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Last alle</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Legg til %1 i godkjentlisten</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Fjern fra godkjentlisten</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Innstilinger</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Last Flash</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Godkjente sider</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Nettside</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="obsolete">Status</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Tillat</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokker</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Tillat for denne økten</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regel</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Nettside</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Sti</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Sikker</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Utløper</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Innhold</translation>
    </message>
    <message>
        <source>true</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>false</source>
        <translation>nei</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Sesjonsinformasjonskapsel</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Informasjonskapsler</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Slett &amp;alle informasjonskapslene</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Legg til &amp;regel</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Unntak for informasjonskapsler</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nytt unntak</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domene:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokker</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Tillat for økt</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Tillat</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Unntak</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Fjern &amp;alle</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Rydd opp</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>Ingen elementer</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Lagre fil</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Nedlasting avbrutt: %1</translation>
    </message>
    <message>
        <source>Error opening save file: %1</source>
        <translation type="obsolete">Feil ved åpning av lagret fil: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Feil ved lagring: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Nettverksfeil: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">sekunder</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 av %2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 av %2 - Stoppet</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MB</translation>
    </message>
    <message>
        <source>Form</source>
        <translation type="obsolete">Skjema</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ikon</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Prøv igjenn</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- %n minutt gjennstår</numerusform>
            <numerusform>- %n minutter gjennstår</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- %n sekund gjennstår</numerusform>
            <numerusform>- %n sekunder gjennstår</numerusform>
        </translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Feil ved skriving til fil: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 av %2 (%3/sek) - %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>Nedlastningsbanen (%1) kunne ikke opprettes.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n nedlasting</numerusform>
            <numerusform>%n nedlastinger</numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Det er %1 aktive nedlastinger
Er du sikker på at du vil avslutte?</translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n minutt gjennstår</numerusform>
            <numerusform>%n minutter gjennstår</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n sekund gjennstår</numerusform>
            <numerusform>%n sekunder gjennstår</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Ingen feil</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Feil ved åpning av: %1: Filen eller banen finnes ikke</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Kan ikke lese %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Innhold i %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Åpne</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historie</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Fjern &amp;alle</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Vis hele historien</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Slett historien</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Slett historien...</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Vil du slette historien?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Tittel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>I dag</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n element</numerusform>
            <numerusform>%n elementer</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Velkommen til Arora!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Arora start</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Søk!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Søkeresultater levert av</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>Om Arora</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Default</source>
        <translation type="obsolete">Standardspråk</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Velg språk</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Du kan bruke at annet språk enn&lt;br&gt;operativsystemets standardspråk.&lt;/p&gt;&lt;p&gt;Velg språk&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Ingen oversettelses filer er installert.</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation>Ingen oversettelsesfiler er installert i %1.</translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Oppgi brukernavn og passord for &quot;%1&quot; på %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Koble til mellomtjener &quot;%1&quot; ved å bruke:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">SSL Feil:

%1

%2

Vil du ignorere disse feilene?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Vil du akseptere alle disse sertifikatene?</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - SSL Feil</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;SSL Feil:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Vil du ignorere disse feilene?&lt;qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Sertifikater:&lt;br/&gt;%1&lt;br/&gt;Vil du akseptere alle disse sertifikatene?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Sertifikater:&lt;br/&gt;%1&lt;br/&gt;Vil du akseptere alle disse sertifikatene?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Utsteder: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Ikke gyldig før: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Gyldig inntil: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Alternative navn:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Navn</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Verdi</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Nettverksovervåker</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Nettverksforespørselser</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Forespørselshode</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Svarhode</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Fjern &amp;alle forespørselser</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Åpne fil</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 er ikke en gyldig OpenSearch 1.1 beskrivelse, eller så finnes den allerede i listen.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Det må være minst en søkemotor her.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>OpenSearch-behandler</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Gjennoprett forvalg</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Legg til</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Beskrivelse:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Gir forslag&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Nøkkelord</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Vil du legge til den følgende motoren i listen over søkemotorer?&lt;br /&gt;&lt;br /&gt;Navn: %1&lt;br /&gt;Søker på: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation></translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation></translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Ikke funnet</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation></translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Koble til mellomtjener</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Filen er ikke en XBEL versjon 1.0 fil.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Ukjent tittel</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>Filen er ikke en OpenSearch 1.1 fil.</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Videresend: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Metode</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adresse</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Svar</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Lengde</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Innholdstype</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Info</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Done</source>
        <translation>Ferdig</translation>
    </message>
    <message>
        <source>Form</source>
        <translatorcomment>Is there a way for things like these be ommitted from translation since they are never shown in the UI? A comment would probably do, so translators don&apos;t have to figure it out :-)</translatorcomment>
        <translation type="obsolete">Skjema</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Merk alt</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Innstilinger</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Home:</source>
        <translation type="obsolete">Hjem:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Sett til nåværende side</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Slett elementer fra historien:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Etter en dag</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Etter en uke</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Etter to uker</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Etter en måned</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Etter ett år</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manuelt</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Åpne lenker fra andre programmer:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">I en fane i det nåværende vinduet</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>I et nytt vindu</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Utforming</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Fastbreddeskrift:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Personvern</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Nettinnhold</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Aktiver programtillegg</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Aktiver Javascript</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Informasjonskapsler</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Aksepter informasjonskapsler:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Alltid</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Kun fra sider du surfer til</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Unntak...</translation>
    </message>
    <message>
        <source>Keep until:</source>
        <translation type="obsolete">Behold inntil:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>De utløper</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Jeg lukker programmet</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Høyst 90 dager</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Informasjonskapsler...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Mellomtjener</translation>
    </message>
    <message>
        <source>Enable proxy</source>
        <translation type="obsolete">Aktiver mellomtjener</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="obsolete">Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Stilsett:</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Spørr om målkatalog hver gang</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Bruk denne katalogen:</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Standard skrift:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Velg...</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Når programmet avsluttes</translation>
    </message>
    <message>
        <source>Enable Images</source>
        <translation type="obsolete">Aktiver bilder</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Faner</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Aktiver faner og vinduer når de opprettes</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Be om bekreftelse for å lukke flere faner</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Ved oppstart:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Vis min hjemmeside</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Vis en blank side</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Gjennoprett vinduer og faner fra forrige gang</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Hjemmeside:</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Vis bilder</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Behold informasjonskapsler inntil:</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Vis kunn en lukkeknapp istedet for en per fane</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Bruk mellomtjener</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Vertsnavn:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Foretrukkne språk for visning av nettsider:</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Blokker sprettoppvinduer</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Åpning av lenker</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Lenker som vil åpnes i et nytt vindu:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>I en ny, aktiv fane i det aktive vinduet</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>I en ny fane i det aktive vinduet</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>I den aktive fanen</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Sikker)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translatorcomment>I don&apos;t know the Norwegian equivalent of this word in this context.</translatorcomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Bruk ClickToFlash på flash-programtillegg</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtrer ut sporingsinformasjonskapsler</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Be om bekreftelse for å lukke flere faner eller viduer</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Lukk programmet når siste fane blir lukket</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Aktiver nettverkshurtiglager</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Maksimal størrelse:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Bruk standardsøkemotoren hvis URLen gitt av brukeren er ugyldig</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Velg katalog...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation>En informasjonskapselsesjon slutter:</translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation>Når jeg skruv av programmet</translation>
    </message>
    <message>
        <source>1 day</source>
        <translation>1 dag</translation>
    </message>
    <message>
        <source>2 days</source>
        <translation>2 dager</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dager</translation>
    </message>
    <message>
        <source>7 days</source>
        <translation>7 dager</translation>
    </message>
    <message>
        <source>30 days</source>
        <translation>30 dager</translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation>AutoFill</translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation>AutoFill skjemaer:</translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation>Brukernavn og passord</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>Rediger...</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Bla igjennom...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Omstart påkrevd</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>Nettverkshurtiglagerkonfigurasjonen har blitt endret. Nettleseren må startes på nytt for å kunne bruke endringene.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Velg katalog</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation>Velg CSS fil</translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Laster...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Finn</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Vis</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Bryt linjer</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Sidens kildekode</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Kildekoden til %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">Ny &amp;fane</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Kopier fane</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Lukk fane</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Lukk &amp;andre faner</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Last fane på nytt</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Last alle faner på nytt</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation>Vis fanelinjen</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Skjul fanelinjen</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>N&amp;y fane</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Lukk fane</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Vis neste fane</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Vis forrige fane</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Nylig lukkede faner</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation type="obsolete">(Uten tittel)</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Vil du virkelig lukke denne siden?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Du har gjort endringer til denne siden og når du lukker den vil du bli tapt.
Vil du virkelig lukke denne siden?
</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Uten tittel</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Lagrede faner</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Laster...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Laster %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Lastet ferdig</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Lasting misslyktes</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Arkiver alle faner som bokmerker</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Google</source>
        <translation type="obsolete">Google</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Ingen nylige søk</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Nylige søk</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Slett nylige søk</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Forslag</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Legg til &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Konfigurer søkemotorer...</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Feil ved lasting av side: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Ved tilkobling til: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.trolltech.com instead of &lt;b&gt;www&lt;/b&gt;.trolltech.com.</source>
        <translation type="obsolete">Sjekk adresselinjen for feil som &lt;b&gt;ww&lt;/b&gt;.trolltech.com isteden for &lt;b&gt;www&lt;/b&gt;.trolltech.com.</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">Hvis adressen er riktig, undersøk nettilkolingen.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Hvis datamaskinen eller nettverket ditt er beskyttet av en brannmur eller mellomtjener, sjekk at nettleseren har adgang til nettverket.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Sjekk adresselinjen for feil som &lt;b&gt;ww&lt;/b&gt;.arora-browser.org isteden for &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Hvis adressen er riktig undersøk nettilkoblingen.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Sender POST forespørsel på nytt</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Forespørselen, sammen med all dataen, må sendes på nytt for å kunne vise siden. Dette kan føre til uforutsette konsekvenser. F.eks., kan den samme handlingen bli utført flere ganger. Vil du fortsette?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Åpne i nytt &amp;vindu</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Åpne i ny &amp;fane</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>&amp;Lagre lenke</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Lag &amp;bokmerke av denne lenken</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Kopier denne lenken</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Åpne bilde i nytt &amp;vindu</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Åpne bilde i ny &amp;fane</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Lagre bilde</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Kopier bilde</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>&amp;Kopier bildeets sti</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Laster...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Søk med...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Legg til i søkeverktøylinja</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Metoden er ikke støttet</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 metoden er ikke støttet.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Søkemotor</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Velg den ønskede søkemotoren</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Søkemotorens navn</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Gi søkemotoren et navn</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation>Blokker bilde</translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Ikke funnet</translation>
    </message>
</context>
</TS>
